==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControl/src/com/clustercontrol/bean/PingRunIntervalConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.bean;

import com.clustercontrol.util.Messages;

/**
 * pingƻ¹Դֳ饹
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class PingRunIntervalConstant {
	
    /** 1 */
    public static final int TYPE_SEC_01 = 1000;

    /** 2 */
    public static final int TYPE_SEC_02 = 2000;
    
    /** 5 */
    public static final int TYPE_SEC_05 = 5000;
    
    
    /** 1 */
    public static final String STRING_SEC_01 = TYPE_SEC_01/1000 + Messages.getString("second");

    /** 2 */
    public static final String STRING_SEC_02 = TYPE_SEC_02/1000 + Messages.getString("second");
    
    /** 5 */
    public static final String STRING_SEC_05 = TYPE_SEC_05/1000 + Messages.getString("second");

    /**
     * ̤ʸѴ
     * 
     * @param type
     * @return
     */
    public static String typeToString(int type) {
        if (type == TYPE_SEC_01) {
            return STRING_SEC_01;
        } else if (type == TYPE_SEC_02) {
            return STRING_SEC_02;
        } else if (type == TYPE_SEC_05) {
            return STRING_SEC_05;
        }
        return "";
    }

    /**
     * ʸ󤫤̤Ѵ
     * 
     * @param type
     * @return
     */
    public static int stringToType(String string) {
        if (string.equals(STRING_SEC_01)) {
            return TYPE_SEC_01;
        } else if (string.equals(STRING_SEC_02)) {
            return TYPE_SEC_02;
        } else if (string.equals(STRING_SEC_05)) {
        	return TYPE_SEC_05;
        }
        return -1;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControl/src/com/clustercontrol/bean/PingRunIntervalConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.bean;

import com.clustercontrol.util.Messages;

/**
 * ping監視実行間隔定数クラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class PingRunIntervalConstant {
	
    /** 1秒 */
    public static final int TYPE_SEC_01 = 1000;

    /** 2秒 */
    public static final int TYPE_SEC_02 = 2000;
    
    /** 5秒 */
    public static final int TYPE_SEC_05 = 5000;
    
    
    /** 1秒 */
    public static final String STRING_SEC_01 = TYPE_SEC_01/1000 + Messages.getString("second");

    /** 2秒 */
    public static final String STRING_SEC_02 = TYPE_SEC_02/1000 + Messages.getString("second");
    
    /** 5秒 */
    public static final String STRING_SEC_05 = TYPE_SEC_05/1000 + Messages.getString("second");

    /**
     * 種別から文字列に変換する
     * 
     * @param type
     * @return
     */
    public static String typeToString(int type) {
        if (type == TYPE_SEC_01) {
            return STRING_SEC_01;
        } else if (type == TYPE_SEC_02) {
            return STRING_SEC_02;
        } else if (type == TYPE_SEC_05) {
            return STRING_SEC_05;
        }
        return "";
    }

    /**
     * 文字列から種別に変換する
     * 
     * @param type
     * @return
     */
    public static int stringToType(String string) {
        if (string.equals(STRING_SEC_01)) {
            return TYPE_SEC_01;
        } else if (string.equals(STRING_SEC_02)) {
            return TYPE_SEC_02;
        } else if (string.equals(STRING_SEC_05)) {
        	return TYPE_SEC_05;
        }
        return -1;
    }
}
